summaryrefslogtreecommitdiff
path: root/nuttx/sched/timer_settime.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/sched/timer_settime.c')
-rw-r--r--nuttx/sched/timer_settime.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/nuttx/sched/timer_settime.c b/nuttx/sched/timer_settime.c
index f09842ad4..d588939ab 100644
--- a/nuttx/sched/timer_settime.c
+++ b/nuttx/sched/timer_settime.c
@@ -95,7 +95,7 @@ static void timer_timeout(int argc, uint32_t itimer);
static void inline timer_sigqueue(FAR struct posix_timer_s *timer)
{
- FAR _TCB *tcb;
+ FAR struct tcb_s *tcb;
/* Get the TCB of the receiving task */
@@ -177,7 +177,7 @@ static void timer_timeout(int argc, uint32_t itimer)
{
#ifndef CONFIG_CAN_PASS_STRUCTS
/* On many small machines, pointers are encoded and cannot be simply cast from
* uint32_t to _TCB*. The following union works around this (see wdogparm_t).
*/
union
@@ -177,7 +177,7 @@ static void timer_timeout(int argc, uint32_t itimer)
#ifndef CONFIG_CAN_PASS_STRUCTS
/* On many small machines, pointers are encoded and cannot be simply cast from
- * uint32_t to _TCB*. The following union works around this (see wdogparm_t).
+ * uint32_t to struct tcb_s*. The following union works around this (see wdogparm_t).
*/
union